@@ -89,8 +89,8 @@ def fixbond_ytm(clean_price: float,
                 daycount: DayCount,
                 frequency: Frequency,
                 thebond: ql.QuantLib.Bond):
-    day_count = ql_day_count[daycount.value]
-    freq = ql_frequency[frequency.value]
+    day_count = ql_day_count[daycount]
+    freq = ql_frequency[frequency]
     ytm = thebond.bondYield(clean_price, 
                                 day_count,
                                 ql.Compounded,
